//
//  MLWanSDK.h
//  SDKDemo
//
//  Created by Stack on 2022/12/15.


#define ML_Wan_SDK_VERSION @"1.0.0" //MLWanSDK基础库版本

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "MLWanSDKInitConfig.h"
#import "MLWanSDKDefines.h"
#import "MLWanSDKGameRoleInfo.h"
#import "MLWanSDKPayOrderInfo.h"

@interface MLWanSDK : NSObject

#pragma mark 单例对象
+ (MLWanSDK *)defaultInstance;

#pragma mark 获取渠道基本信息

// 获取渠道唯一标识，与服务器端channelID一致，任何时刻都可调用
- (NSString *)channelType;

@property (nonatomic, strong) MLWanSDKInitConfig *config;

@end

@interface MLWanSDK(Base)

#pragma mark 初始化



/**
 @brief 应用初始化 完成后会发送通知kMLWanSDKNotiInitDidFinished
 @param configure 初始化配置类
 @result 错误码
 @note 必接
 */
- (int)initWithConfig:(MLWanSDKInitConfig *)config application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

@end

#pragma mark - 用户部分 登录 注册 登出

@interface MLWanSDK(Account)

/**
 @brief 登录接口 ，登录后会发送kMLWanSDKNotiLogin通知
 @result 错误码
 @note 必接
 */
- (int)login;

/**
 @brief 登出接口 代码调用注销
 @result 错误码
 @note 成功调用该接口后，SDK会发出kMLWanSDKNotiLogout通知
 */
- (int)logout;

// 登录后获取用户uid,这个uid在渠道上唯一，多个渠道的用户uid可能重复
- (NSString *)userId;
// 登录后获取userToken可用于验证用户信息
- (NSString *)userToken;
// 登录后获取loginTime可用于验证用户信息
- (NSString *)loginTime;
/** 查询渠道实名认证信息 */
- (NSDictionary *)realNameInfo;
/**
 @brief 调用渠道实名认证
 @result 错误码若渠道没有提供此方法会返回非0
 @note 结果会发送kMLWanSDKNotiRealAuth通知
*/
- (int)realAuth;

// 创建角色、进入游戏角色、角色信息变更时调用（比如升级，isCreate表示是否为创建角色
- (void)updateRoleInfoWith:(MLWanSDKGameRoleInfo *)info isCreate:(BOOL)isCreate;

@end

//MARK:- 充值
@interface MLWanSDK(Pay)

/**
 @brief 商品购买
 *  @param orderInfo
 *  @param roleInfo
 @result 错误码
 */
- (int)payOrderInfo:(MLWanSDKPayOrderInfo *)orderInfo
           roleInfo:(MLWanSDKGameRoleInfo *)roleInfo;

@end

#pragma mark - 界面控制
@interface MLWanSDK(UISetting)

#pragma mark 浮动条
/**
 @brief showToolBar:
 @brief 浮动工具栏，建议显示在左上角
 @result 错误码
 @note
 */
- (int)showToolBar:(ML_WAN_SDK_TOOLBAR_PLACE)place;
//隐藏浮动工具栏
- (int)hideToolBar;
@end

@interface MLWanSDK(Extend)

/**
 @brief 进入用户中心 如用户注销登录会发送kMLWanSDKNotiLogout（可多次触发）
 @result 错误码
 */
- (int)enterUserCenter;

//***********************应用生命周期的回调*******************//
//在应用对应的生命周期回调中调用
/**
 @brief - (BOOL)application:(UIApplication *)application handleOpenURL:(NSURL *)url;
 @brief - (BOOL)application:(UIApplication *)application openURL:(NSURL *)url sourceApplication:(nullable NSString *)sourceApplication annotation:(id)annotation
 @brief - (BOOL)application:(UIApplication *)app openURL:(NSURL *)url options:(NSDictionary<NSString*, id> *)options
 @brief 渠道处理应用跳转
 @result 错误码
 @note 必接
 */

- (int)openURL:(NSURL *)url application:(UIApplication *)application;
- (int)openURL:(NSURL *)url sourceApplication:(NSString *)sourceApp application:(UIApplication *)application annotation:(id)annotation;
- (int)openURL:(NSURL *)url application:(UIApplication *)app options:(NSDictionary <NSString *, id>*)options;


/**
 @brief application:didRegisterForRemoteNotificationsWithDeviceToken:
 @brief 推送消息
 @result 错误码
 @note 必接
 */
- (int)application:(UIApplication*)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData*)deviceToken;

/**
 @brief application:didFailToRegisterForRemoteNotificationsWithError:
 @brief 推送消息
 @result 错误码
 @note 必接
 */
- (int)application:(UIApplication*)application didFailToRegisterForRemoteNotificationsWithError:(NSError*)error;
- (int)application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo;
- (int)applicationWillResignActive:(UIApplication *)application;
- (int)applicationDidEnterBackground:(UIApplication *)application;
- (int)applicationWillEnterForeground:(UIApplication *)application;
- (int)applicationDidBecomeActive:(UIApplication *)application;
- (int)applicationWillTerminate:(UIApplication *)application;
- (NSUInteger)application:(UIApplication *)application supportedInterfaceOrientationsForWindow:(UIWindow *)window;
- (BOOL)application:(UIApplication *)application continueUserActivity:(NSUserActivity *)userActivity restorationHandler:(void(^)(NSArray *  restorableObjects))restorationHandler;

@end


